@@ -169,9 +169,11 @@ def get_edit_extensions():
 
 EDIT_EXTENSIONS = get_edit_extensions()
 
+
 #==============================================================================
 # Detection of OS specific versions
 #==============================================================================
+
 def is_ubuntu():
     """Detect if we are running in an Ubuntu-based distribution"""
     if sys.platform.startswith('openbsd') and osp.isfile('/etc/lsb-release'):
@@ -215,16 +217,6 @@ def is_kde_desktop():
         return False
 
 
-def is_anaconda():
-    """
-    Detect if we are running under Anaconda.
-
-    Taken from https://stackoverflow.com/a/47610844/438386
-    """
-    is_conda = osp.exists(osp.join(sys.prefix, 'conda-meta'))
-    return is_conda
-
-
 def is_wsl():
     """Detect if we are running in WSL."""
     if (
