@@ -18,10 +18,6 @@ from spyder.utils import programs
 
 HERE = osp.dirname(osp.abspath(__file__))
 
-# Python 3.8
-PY38 = sys.version_info[:2] == (3, 8)
-
-
 # =============================================================================
 # Kind of dependency
 # =============================================================================
@@ -34,7 +30,7 @@ PLUGIN = 'spyder plugins'
 # Versions
 # =============================================================================
 # Hard dependencies
-AIOHTTP_REQVER = '>=3.9.3'
+AIOHTTP_REQVER = '>=3.11.2'
 APPLAUNCHSERVICES_REQVER = '>=0.3.0'
 ASYNCSSH_REQVER = '>=2.14.0,<3.0.0'
 ATOMICWRITES_REQVER = '>=1.2.0'
@@ -45,7 +41,8 @@ COOKIECUTTER_REQVER = '>=1.6.0'
 DIFF_MATCH_PATCH_REQVER = '>=20181111'
 IMPORTLIB_METADATA_REQVER = '>=4.6.0'
 INTERVALTREE_REQVER = '>=3.0.2'
-IPYTHON_REQVER = ">=8.12.2,<8.13.0" if PY38 else ">=8.13.0,<9.0.0,!=8.17.1"
+IPYTHON_REQVER = ">=8.15.0,<10.0.0,!=8.17.1,!=9.1.0,!=9.2.0,!=9.3.0,!=9.4.0"
+IPYTHON_PYGMENTS_LEXERS_REQVER = ">=1.0"
 JEDI_REQVER = '>=0.17.2,<0.20.0'
 JELLYFISH_REQVER = '>=0.7'
 JSONSCHEMA_REQVER = '>=3.2.0'
@@ -61,8 +58,9 @@ PYGITHUB_REQVER = '>=2.3.0'
 PYGMENTS_REQVER = '>=2.0'
 PYLINT_REQVER = '>=3.1,<4'
 PYLINT_VENV_REQVER = '>=3.0.2'
-PYLSP_REQVER = '>=1.12.0,<1.13.0'
+PYLSP_REQVER = '>=1.13.0,<1.14.0'
 PYLSP_BLACK_REQVER = '>=2.0.0,<3.0.0'
+PYLSP_RUFF_REQVER = '>=2.3.0,<3.0.0'
 PYLS_SPYDER_REQVER = '>=0.4.0'
 PYUCA_REQVER = '>=1.2'
 PYXDG_REQVER = '>=0.26'
@@ -70,11 +68,11 @@ PYZMQ_REQVER = '>=24.0.0'
 QDARKSTYLE_REQVER = '>=3.2.0,<3.3.0'
 QSTYLIZER_REQVER = '>=0.2.2'
 QTAWESOME_REQVER = '>=1.4.0,<1.5.0'
-QTCONSOLE_REQVER = '>=5.6.1,<5.7.0'
+QTCONSOLE_REQVER = '>=5.7.0,<5.8.0'
 QTPY_REQVER = '>=2.4.0'
 RTREE_REQVER = '>=0.9.7'
 SPHINX_REQVER = '>=0.6.6'
-SPYDER_KERNELS_REQVER = '>=3.0.5,<3.1.0'
+SPYDER_KERNELS_REQVER = '>=3.1.0,<3.2.0'
 SUPERQT_REQVER = '>=0.6.2,<1.0.0'
 TEXTDISTANCE_REQVER = '>=4.2.0'
 THREE_MERGE_REQVER = '>=0.1.1'
@@ -147,6 +145,10 @@ DESCRIPTIONS = [
      'package_name': "IPython",
      'features': _("IPython interactive python environment"),
      'required_version': IPYTHON_REQVER},
+    {'modname': "ipython_pygments_lexers",
+     'package_name': "ipython_pygments_lexers",
+     'features': _("IPython lexers for syntax highlighting"),
+     'required_version': IPYTHON_PYGMENTS_LEXERS_REQVER},
     {'modname': "jedi",
      'package_name': "jedi",
      'features': _("Main backend for the Python Language Server"),
@@ -219,6 +221,10 @@ DESCRIPTIONS = [
      'features': _("Autoformat Python files in the Editor with the Black "
                    "package"),
      'required_version': PYLSP_BLACK_REQVER},
+    {'modname': 'pylsp_ruff',
+     'package_name': 'python-lsp-ruff',
+     'features': _("Provide linting with the Ruff package"),
+     'required_version': PYLSP_RUFF_REQVER},
     {'modname': 'pyls_spyder',
      'package_name': 'pyls-spyder',
      'features': _('Spyder plugin for the Python LSP Server'),
