@@ -8,6 +8,7 @@
 
 # Standard library imports
 from ast import literal_eval
+import asyncio
 import glob
 from getpass import getuser
 import importlib
@@ -71,7 +72,7 @@ def get_temp_dir(suffix=None):
     return tempdir
 
 
-def is_program_installed(basename, extra_paths=[]):
+def is_program_installed(basename, extra_paths=None):
     """
     Return program absolute path if installed in PATH.
     Otherwise, return None.
@@ -83,6 +84,7 @@ def is_program_installed(basename, extra_paths=[]):
 
     On macOS systems, a .app is considered installed if it exists.
     """
+    extra_paths = [] if extra_paths is None else extra_paths
     home = get_home_dir()
     if (
         sys.platform == 'darwin'
@@ -91,6 +93,8 @@ def is_program_installed(basename, extra_paths=[]):
     ):
         return basename
 
+    pixi = [osp.join(home, '.pixi', 'bin')]
+
     if os.name == 'posix':
         pyenv = [
             osp.join(home, '.pyenv', 'bin'),
@@ -111,20 +115,25 @@ def is_program_installed(basename, extra_paths=[]):
     conda = [osp.join(*p, 'condabin') for p in itertools.product(a, b)]
 
     for path in (
-        extra_paths + conda + pyenv + os.getenv('PATH', []).split(os.pathsep)
+        extra_paths
+        + conda
+        + pyenv
+        + pixi
+        + os.getenv("PATH", []).split(os.pathsep)
     ):
         abspath = osp.join(path, basename)
         if osp.isfile(abspath):
             return abspath
 
 
-def find_program(basename, extra_paths=[]):
+def find_program(basename, extra_paths=None):
     """
     Find program in PATH and return absolute path
 
     Try adding .exe or .bat to basename on Windows platforms
     (return None if not found)
     """
+    extra_paths = [] if extra_paths is None else extra_paths
     names = [basename]
     if os.name == 'nt':
         # Windows platforms
@@ -194,7 +203,7 @@ def alter_subprocess_kwargs_by_platform(**kwargs):
     return kwargs
 
 
-def run_shell_command(cmdstr, **subprocess_kwargs):
+def run_shell_command(cmdstr, asynchronous=False, **subprocess_kwargs):
     """
     Execute the given shell command.
 
@@ -202,16 +211,28 @@ def run_shell_command(cmdstr, **subprocess_kwargs):
 
     If 'shell' is given in subprocess_kwargs it must be True,
     otherwise ProgramError will be raised.
-    .
+
     If 'executable' is not given in subprocess_kwargs, it will
     be set to the value of the SHELL environment variable.
 
     Note that stdin, stdout and stderr will be set by default
     to PIPE unless specified in subprocess_kwargs.
 
-    :str cmdstr: The string run as a shell command.
-    :subprocess_kwargs: These will be passed to subprocess.Popen.
+    Parameters
+    ----------
+    cmdstr : str
+        The string run as a shell command.
+    asynchronous : bool (False)
+        Whether to return a subprocess.Popen or asyncio.subprocess.Process.
+    **subprocess_kwargs : keyword arguments
+        These will be passed to subprocess.Popen.
     """
+    popen = subprocess.Popen
+    pipe = subprocess.PIPE
+    if asynchronous:
+        popen = asyncio.create_subprocess_shell
+        pipe = asyncio.subprocess.PIPE
+
     if 'shell' in subprocess_kwargs and not subprocess_kwargs['shell']:
         raise ProgramError('The "shell" kwarg may be omitted, but if '
                            'provided it must be True.')
@@ -226,10 +247,10 @@ def run_shell_command(cmdstr, **subprocess_kwargs):
             subprocess_kwargs['executable'] = os.getenv('SHELL')
 
     for stream in ['stdin', 'stdout', 'stderr']:
-        subprocess_kwargs.setdefault(stream, subprocess.PIPE)
+        subprocess_kwargs.setdefault(stream, pipe)
     subprocess_kwargs = alter_subprocess_kwargs_by_platform(
         **subprocess_kwargs)
-    return subprocess.Popen(cmdstr, **subprocess_kwargs)
+    return popen(cmdstr, **subprocess_kwargs)
 
 
 def run_program(program, args=None, **subprocess_kwargs):
@@ -657,11 +678,14 @@ def python_script_exists(package=None, module=None):
             return path
 
 
-def run_python_script(package=None, module=None, args=[], p_args=[]):
+def run_python_script(package=None, module=None, args=None, p_args=None):
     """
     Run Python script in a separate process
     package=None -> module is in sys.path (standard library modules)
     """
+    args = [] if args is None else args
+    p_args = [] if p_args is None else p_args
+
     assert module is not None
     assert isinstance(args, (tuple, list)) and isinstance(p_args, (tuple, list))
     path = python_script_exists(package, module)
@@ -978,7 +1002,8 @@ def check_version(actver, version, cmp_op):
 def get_module_version(module_name, interpreter=None):
     """Return module version or None if version can't be retrieved."""
     if interpreter:
-        cmd = dedent("""
+        cmd = dedent(
+            """
             try:
                 import {} as mod
             except Exception:
@@ -989,8 +1014,19 @@ def get_module_version(module_name, interpreter=None):
             """
         ).format(module_name)
 
-        # Use clean environment
-        proc = run_program(interpreter, ['-c', cmd], env={})
+        # Use clean environment while preserving basic environment variables
+        # needed to properly detect installed modules like `spyder-kernels`
+        # from system-wide Python installations on Windows.
+        # See spyder-ide/spyder#20968
+        env = {}
+        if os.name == "nt":
+            if "USERPROFILE" in os.environ:
+                env["USERPROFILE"] = os.environ["USERPROFILE"]
+
+            if "APPDATA" in os.environ:
+                env["APPDATA"] = os.environ["APPDATA"]
+
+        proc = run_program(interpreter, ['-c', cmd], env=env)
         stdout, stderr = proc.communicate()
         stdout = stdout.decode().strip()
 
